# ts-tariffs

Tariff calculation for time series consumption data.

## Installation

`pip install ts-tariffs`

## Usage and features
ts-tariffs can deal with any combination of typical electricity charges: 
- Connection charges 
- Single rate charges
- Time of use charges
- Demand charges, including those which are split into time of use
- Block charges

## Under development
- units handling

